Character vector with every symbology accepted by the format argument of
JsBarcode(). See barcode_format_info for what each format accepts.
Character vector with every symbology accepted by the format argument of
JsBarcode(). See barcode_format_info for what each format accepts.